/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayButton from '@clayui/button';
import ClayModal from '@clayui/modal';
import ClayTable from '@clayui/table';
import React from 'react';

const ImportPreviewModalBody = ({
	closeModal,
	fieldsSelections,
	fileContent,
	startImport,
}) => {
	const dbFieldsSelected = Object.keys(fieldsSelections).sort();

	return (
		<>
			<ClayModal.Header>
				{Liferay.Language.get('preview')}
			</ClayModal.Header>

			<ClayModal.Body className="p-0" scrollable>
				<ClayTable borderless hover={false}>
					<ClayTable.Head>
						<ClayTable.Row>
							{dbFieldsSelected.map((dbFieldName) => (
								<ClayTable.Cell headingCell key={dbFieldName}>
									{dbFieldName}
								</ClayTable.Cell>
							))}
						</ClayTable.Row>
					</ClayTable.Head>

					<ClayTable.Body>
						{fileContent.map((rowData, index) => (
							<ClayTable.Row
								key={`${JSON.stringify(rowData)}_${index}`}
							>
								{dbFieldsSelected.map((dbField) => {
									const fileField = fieldsSelections[dbField];

									return (
										<ClayTable.Cell
											key={dbField}
											truncate="true"
										>
											{JSON.stringify(rowData[fileField])}
										</ClayTable.Cell>
									);
								})}
							</ClayTable.Row>
						))}
					</ClayTable.Body>
				</ClayTable>
			</ClayModal.Body>

			<ClayModal.Footer
				last={
					<ClayButton.Group spaced>
						<ClayButton
							displayType="secondary"
							onClick={closeModal}
						>
							{Liferay.Language.get('cancel')}
						</ClayButton>

						<ClayButton
							data-testid="start-import"
							displayType="primary"
							onClick={startImport}
							type="submit"
						>
							{Liferay.Language.get('start-import')}
						</ClayButton>
					</ClayButton.Group>
				}
			/>
		</>
	);
};

export default ImportPreviewModalBody;
